==> hyades.ies.sdk.3.0.1.1_20041013_1609.zip: org/eclipse/hyades/logging/events/cbe/util/EventMessages_pt_BR.java <==
package org.eclipse.hyades.logging.events.cbe.util;

import java.util.ListResourceBundle;
import org.eclipse.hyades.logging.events.cbe.util.EventMessages;

/**********************************************************************
 * Copyright (c) 2004 Hyades project.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/

/**
 * Portuguese (Brazil) resource bundle.
 * 
 * @author Denilson Nastacio
 * @version 1.0.1
 * @since 1.0
 */
public class EventMessages_pt_BR extends ListResourceBundle {

    /**************************************************************************
    * Implements java.util.ListResourceBundle.getContents().
    * @see java.util.ListResourceBundle#getContents
    **************************************************************************/

    public Object[][] getContents() {
        return contents_;
    }

    /**************************************************************************
    * Resource table
    **************************************************************************/
    private final static Object[][] contents_ = { { EventMessages.LOG_INVALID_JNDI_REFERENCE_EXC_, "IWAT0187E A refer\u00eancia obtida do nome JNDI especificado n\u00e3o \u00e9 uma refer\u00eancia a uma f\u00e1brica de eventos.\nNome JNDI: {0}" }, {
        EventMessages.LOG_FAILED_TO_SERIALIZE_CONTENT_HANDLER_EXC_, "IWAT0188E A rotina de tratamento do conte\u00fado de eventos n\u00e3o pode ser convertida em formato bin\u00e1rio.\nInforma\u00e7\u00f5es adicionais, se houver: {0}" }, {
        EventMessages.LOG_FAILED_TO_DESERIALIZE_CONTENT_HANDLER_EXC_, "IWAT0189E A rotina de tratamento do conte\u00fado de eventos referenciada por este nome JNDI n\u00e3o pode ser convertida novamente de seu formato bin\u00e1rio.\nNome JNDI: {0} \nInforma\u00e7\u00f5es adicionais, se houver: {1}" }, {
        EventMessages.LOG_INVALID_GLOBAL_INSTANCE_ID_EXC_, "IWAT0190E O identificador de evento na propriedade especificada do Common Base Event deve iniciar com um caractere alfab\u00e9tico.\nPropriedade: {0} \nIdentificador: {1} " }, {
        EventMessages.LOG_VALUE_ARRAY_SIZE_MISMATCH_EXC_, "IWAT0191E O elemento de dados estendidos especificado \u00e9 um tipo que requer um elemento em sua matriz de valores, mas cont\u00e9m m\u00faltiplos valores.\nElemento de dados estendidos: {1}\nTipo: {2} \nN\u00famero de valores: {0} " }, {
        EventMessages.LOG_INVALID_TYPE_CONVERSION_EXC_, "IWAT0192E O valor no elemento de dados estendidos n\u00e3o pode ser convertido para o tipo especificado.\nElemento de dados estendidos: {2} \nValor: {0} \nTipo: {1}" }, {
        EventMessages.LOG_EXTENDED_DATA_INVALID_TYPE_EXC_, "IWAT0193E O elemento de dados estendidos possui um tipo que n\u00e3o \u00e9 v\u00e1lido.\nElemento de dados estendidos: {0}\nTipo: {1}" }, {
        EventMessages.LOG_EXTENDED_DATA_VALUE_NULL_EXC_, "IWAT0194E O elemento de dados estendidos cont\u00e9m um valor nulo. Se o tipo for uma matriz, um ou mais elementos ser\u00e3o nulos.\nElemento de dados estendidos: {0} \nTipo: {1} " }, {
        EventMessages.LOG_EXTENDED_DATA_INVALID_BOOLEAN_EXC_, "IWAT0195E O elemento de dados estendidos cont\u00e9m uma cadeia booleana inv\u00e1lida.\nElemento de dados estendidos: {0}\nTipo: {1} \nCadeia: {2}" }, {
        EventMessages.LOG_EXTENDED_DATA_INVALID_DATE_EXC_, "IWAT0196E O elemento de dados estendidos cont\u00e9m uma cadeia dateTime inv\u00e1lida.\nElemento de dados estendidos: {0}\nTipo: {1}\nCadeia dateTime: {2}" }, {
        EventMessages.LOG_EXTENDED_DATA_INVALID_HEX_BINARY_1_EXC_, "IWAT0197E O elemento de dados estendidos deve conter um n\u00famero par de caracteres na propriedade hexValue.\nElemento de dados estendidos: {0} \nTipo: {1} \nValor: {2} " }, {
        EventMessages.LOG_EXTENDED_DATA_INVALID_HEX_BINARY_2_EXC_, "IWAT0198E O elemento de dados estendidos cont\u00e9m um caractere n\u00e3o-hexadecimal na propriedade hexValue.\nNome do elemento de dados estendidos: {0} \nTipo: {1} \nValor: {2} \nCaractere n\u00e3o-hexadecimal: {3} " }, {
        EventMessages.LOG_INVALID_SITUATION_TYPE_EXC_, "IWAT0199E O valor da propriedade especificada n\u00e3o \u00e9 v\u00e1lido.\nPropriedade: {0} \nValor: {1} \nValores v\u00e1lidos: {2} " }, {
        EventMessages.LOG_INVALID_CREATION_TIME_EXC_, "IWAT0200E O valor dateTime para a propriedade especificada n\u00e3o p\u00f4de ser analisado.\nPropriedade: {0} \nValor: {1} " }, {
        EventMessages.LOG_INVALID_LIST_ELEMENT_LENGTH_EXC_, "IWAT0201E O comprimento de um elemento na propriedade especificada excede o n\u00famero m\u00e1ximo de caracteres.\nPropriedade: {1} \nElemento: {0} \nComprimento m\u00e1ximo: {2} " }, {
        EventMessages.LOG_VALUE_OUT_OF_RANGE_EXC_, "IWAT0202E O valor da propriedade est\u00e1 fora do intervalo inv\u00e1lido.\nPropriedade: {1} \nValor: {0} \nIntervalo v\u00e1lido: {2} a {3} " }, {
        EventMessages.LOG_MISSING_REQUIRED_ATTRIBUTE_EXC_, "IWAT0203E Uma propriedade obrigat\u00f3ria est\u00e1 faltando no Common Base Event.\nPropriedade: {0} " }, {
        EventMessages.LOG_MUTUALLY_EXCLUSIVE_ATTRIBUTES_EXC_, "IWAT0204E O Common Base Event cont\u00e9m propriedades que s\u00e3o mutuamente exclusivas.\nPropriedade 1: {0} \nPropriedade 2: {1} " }, {
        EventMessages.LOG_INVALID_VERSION_EXC_, "IWAT0205E A vers\u00e3o na propriedade {0} n\u00e3o \u00e9 v\u00e1lida. O valor deve ser 1.0.1.\nValor: {1} " }, {
        EventMessages.LOG_INVALID_GLOBAL_INSTANCE_ID_LENGTH_EXC_, "IWAT0206E O comprimento do identificador na propriedade especificada do Common Base Event est\u00e1 fora do intervalo v\u00e1lido de 32 a 64 caracteres.\nPropriedade: {0} \nValor: {1} " }, {
        EventMessages.LOG_INVALID_LENGTH_EXC_, "IWAT0207E O comprimento do valor na propriedade especificada do Common Base Event excede o n\u00famero m\u00e1ximo de caracteres.\nPropriedade: {0} \nValor: {1} \nComprimento: {2} \nN\u00famero m\u00e1ximo de caracteres: {3} " }, {
        EventMessages.LOG_INVALID_LENGTH_RANGE_EXC_, "IWAT0208E O comprimento do valor na propriedade especificada do Common Base Event est\u00e1 fora do intervalo v\u00e1lido.\nPropriedade: {0} \nValor: {1} \nComprimento: {2} \nIntervalo v\u00e1lido de comprimento: {3} " }, {
        EventMessages.LOG_MISSING_ATTRIBUTES_EXC_, "IWAT0209E As propriedades especificadas devem estar todas presentes ou todas ausentes.\nPropriedades: {0} " }, {
        EventMessages.LOG_INCONSISTENT_ATTRIBUTES_EXC_, "IWAT0210E Quando o valor da propriedade {0} no Common Base Event \u00e9 igual a {1}, a lista especificada de propriedades n\u00e3o deve estar presente.\nLista: {2} " }, {
        EventMessages.LOG_CATEGORY_MISMATCH_EXC_, "IWAT0211E O valor para a propriedade {0} n\u00e3o corresponde \u00e0 classe de objeto referenciado pela propriedade situationType.\nValor: {1} \nClasse de objeto: {2}." }, {
        EventMessages.LOG_COMPONENT_IDENTIFICATION_INVALID_LOCATION_TYPE_EXC_, "IWAT0212E A identifica\u00e7\u00e3o de componentes com o componente [{0}] possui um tipo de local inv\u00e1lido: [{1}]" }, {
	    EventMessages.LOG_EVENT_SAX_PARSER_UNEXPECTED_XML_ELEMENT_EXC_, "Unexpected element ''{0}'' at line {1}, column {2}." }, {
	    EventMessages.LOG_EVENT_SAX_PARSER_INCORRECT_XML_ELEMENT_EXC_ , "Expected element ''{0}'' , but found element ''{1}'' at line {2}, column {3}."}
    };
}

==> hyades.ies.sdk.3.0.2_20050225_1641.zip: org/eclipse/hyades/logging/events/cbe/util/EventMessages_pt_BR.java <==
package org.eclipse.hyades.logging.events.cbe.util;

import java.util.ListResourceBundle;
import org.eclipse.hyades.logging.events.cbe.util.EventMessages;

/**********************************************************************
 * Copyright (c) 2004 Hyades project.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/

/**
 * Portuguese (Brazil) resource bundle.
 * 
 * @author Denilson Nastacio
 * @version 1.0.1
 * @since 1.0
 */
public class EventMessages_pt_BR extends ListResourceBundle {

    /**************************************************************************
    * Implements java.util.ListResourceBundle.getContents().
    * @see java.util.ListResourceBundle#getContents
    **************************************************************************/

    public Object[][] getContents() {
        return contents_;
    }

    /**************************************************************************
    * Resource table
    **************************************************************************/
    private final static Object[][] contents_ = { { EventMessages.LOG_INVALID_JNDI_REFERENCE_EXC_, "IWAT0187E A refer\u00eancia obtida do nome JNDI especificado n\u00e3o \u00e9 uma refer\u00eancia a uma f\u00e1brica de eventos.\nNome JNDI: {0}" }, {
        EventMessages.LOG_FAILED_TO_SERIALIZE_CONTENT_HANDLER_EXC_, "IWAT0188E A rotina de tratamento do conte\u00fado de eventos n\u00e3o pode ser convertida em formato bin\u00e1rio.\nInforma\u00e7\u00f5es adicionais, se houver: {0}" }, {
        EventMessages.LOG_FAILED_TO_DESERIALIZE_CONTENT_HANDLER_EXC_, "IWAT0189E A rotina de tratamento do conte\u00fado de eventos referenciada por este nome JNDI n\u00e3o pode ser convertida novamente de seu formato bin\u00e1rio.\nNome JNDI: {0} \nInforma\u00e7\u00f5es adicionais, se houver: {1}" }, {
        EventMessages.LOG_INVALID_GLOBAL_INSTANCE_ID_EXC_, "IWAT0190E O identificador de evento na propriedade especificada do Common Base Event deve iniciar com um caractere alfab\u00e9tico.\nPropriedade: {0} \nIdentificador: {1} " }, {
        EventMessages.LOG_VALUE_ARRAY_SIZE_MISMATCH_EXC_, "IWAT0191E O elemento de dados estendidos especificado \u00e9 um tipo que requer um elemento em sua matriz de valores, mas cont\u00e9m m\u00faltiplos valores.\nElemento de dados estendidos: {1}\nTipo: {2} \nN\u00famero de valores: {0} " }, {
        EventMessages.LOG_INVALID_TYPE_CONVERSION_EXC_, "IWAT0192E O valor no elemento de dados estendidos n\u00e3o pode ser convertido para o tipo especificado.\nElemento de dados estendidos: {2} \nValor: {0} \nTipo: {1}" }, {
        EventMessages.LOG_EXTENDED_DATA_INVALID_TYPE_EXC_, "IWAT0193E O elemento de dados estendidos possui um tipo que n\u00e3o \u00e9 v\u00e1lido.\nElemento de dados estendidos: {0}\nTipo: {1}" }, {
        EventMessages.LOG_EXTENDED_DATA_VALUE_NULL_EXC_, "IWAT0194E O elemento de dados estendidos cont\u00e9m um valor nulo. Se o tipo for uma matriz, um ou mais elementos ser\u00e3o nulos.\nElemento de dados estendidos: {0} \nTipo: {1} " }, {
        EventMessages.LOG_EXTENDED_DATA_INVALID_BOOLEAN_EXC_, "IWAT0195E O elemento de dados estendidos cont\u00e9m uma cadeia booleana inv\u00e1lida.\nElemento de dados estendidos: {0}\nTipo: {1} \nCadeia: {2}" }, {
        EventMessages.LOG_EXTENDED_DATA_INVALID_DATE_EXC_, "IWAT0196E O elemento de dados estendidos cont\u00e9m uma cadeia dateTime inv\u00e1lida.\nElemento de dados estendidos: {0}\nTipo: {1}\nCadeia dateTime: {2}" }, {
        EventMessages.LOG_EXTENDED_DATA_INVALID_HEX_BINARY_1_EXC_, "IWAT0197E O elemento de dados estendidos deve conter um n\u00famero par de caracteres na propriedade hexValue.\nElemento de dados estendidos: {0} \nTipo: {1} \nValor: {2} " }, {
        EventMessages.LOG_EXTENDED_DATA_INVALID_HEX_BINARY_2_EXC_, "IWAT0198E O elemento de dados estendidos cont\u00e9m um caractere n\u00e3o-hexadecimal na propriedade hexValue.\nNome do elemento de dados estendidos: {0} \nTipo: {1} \nValor: {2} \nCaractere n\u00e3o-hexadecimal: {3} " }, {
        EventMessages.LOG_INVALID_SITUATION_TYPE_EXC_, "IWAT0199E O valor da propriedade especificada n\u00e3o \u00e9 v\u00e1lido.\nPropriedade: {0} \nValor: {1} \nValores v\u00e1lidos: {2} " }, {
        EventMessages.LOG_INVALID_CREATION_TIME_EXC_, "IWAT0200E O valor dateTime para a propriedade especificada n\u00e3o p\u00f4de ser analisado.\nPropriedade: {0} \nValor: {1} " }, {
        EventMessages.LOG_INVALID_LIST_ELEMENT_LENGTH_EXC_, "IWAT0201E O comprimento de um elemento na propriedade especificada excede o n\u00famero m\u00e1ximo de caracteres.\nPropriedade: {1} \nElemento: {0} \nComprimento m\u00e1ximo: {2} " }, {
        EventMessages.LOG_VALUE_OUT_OF_RANGE_EXC_, "IWAT0202E O valor da propriedade est\u00e1 fora do intervalo inv\u00e1lido.\nPropriedade: {1} \nValor: {0} \nIntervalo v\u00e1lido: {2} a {3} " }, {
        EventMessages.LOG_MISSING_REQUIRED_ATTRIBUTE_EXC_, "IWAT0203E Uma propriedade obrigat\u00f3ria est\u00e1 faltando no Common Base Event.\nPropriedade: {0} " }, {
        EventMessages.LOG_MUTUALLY_EXCLUSIVE_ATTRIBUTES_EXC_, "IWAT0204E O Common Base Event cont\u00e9m propriedades que s\u00e3o mutuamente exclusivas.\nPropriedade 1: {0} \nPropriedade 2: {1} " }, {
        EventMessages.LOG_INVALID_VERSION_EXC_, "IWAT0205E A vers\u00e3o na propriedade {0} n\u00e3o \u00e9 v\u00e1lida. O valor deve ser 1.0.1.\nValor: {1} " }, {
        EventMessages.LOG_INVALID_GLOBAL_INSTANCE_ID_LENGTH_EXC_, "IWAT0206E O comprimento do identificador na propriedade especificada do Common Base Event est\u00e1 fora do intervalo v\u00e1lido de 32 a 64 caracteres.\nPropriedade: {0} \nValor: {1} " }, {
        EventMessages.LOG_INVALID_LENGTH_EXC_, "IWAT0207E O comprimento do valor na propriedade especificada do Common Base Event excede o n\u00famero m\u00e1ximo de caracteres.\nPropriedade: {0} \nValor: {1} \nComprimento: {2} \nN\u00famero m\u00e1ximo de caracteres: {3} " }, {
        EventMessages.LOG_INVALID_LENGTH_RANGE_EXC_, "IWAT0208E O comprimento do valor na propriedade especificada do Common Base Event est\u00e1 fora do intervalo v\u00e1lido.\nPropriedade: {0} \nValor: {1} \nComprimento: {2} \nIntervalo v\u00e1lido de comprimento: {3} " }, {
        EventMessages.LOG_MISSING_ATTRIBUTES_EXC_, "IWAT0209E As propriedades especificadas devem estar todas presentes ou todas ausentes.\nPropriedades: {0} " }, {
        EventMessages.LOG_INCONSISTENT_ATTRIBUTES_EXC_, "IWAT0210E Quando o valor da propriedade {0} no Common Base Event \u00e9 igual a {1}, a lista especificada de propriedades n\u00e3o deve estar presente.\nLista: {2} " }, {
        EventMessages.LOG_CATEGORY_MISMATCH_EXC_, "IWAT0211E O valor para a propriedade {0} n\u00e3o corresponde \u00e0 classe de objeto referenciado pela propriedade situationType.\nValor: {1} \nClasse de objeto: {2}." }, {
        EventMessages.LOG_COMPONENT_IDENTIFICATION_INVALID_LOCATION_TYPE_EXC_, "IWAT0212E A identifica\u00e7\u00e3o de componentes com o componente [{0}] possui um tipo de local inv\u00e1lido: [{1}]" }, {
	    EventMessages.LOG_EVENT_SAX_PARSER_UNEXPECTED_XML_ELEMENT_EXC_, "Unexpected element ''{0}'' at line {1}, column {2}." }, {
		EventMessages.LOG_EVENT_SAX_PARSER_INCORRECT_XML_ELEMENT_EXC_ , "Expected element ''{0}'' , but found element ''{1}'' at line {2}, column {3}."}, {
		EventMessages.LOG_EVENT_SAX_PARSER_INVALID_XML_ATTRIBUTE_EXC_ , "IWAT0157E The ''{0}'' attribute contains the invalid value ''{1}'' at line {2}, column {3}."}
    };
}
